package com.dgtly.system.service.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.EntryPassMapper;
import com.dgtly.system.domain.EntryPass;
import com.dgtly.system.service.IEntryPassService;
import com.dgtly.common.core.text.Convert;

/**
 * 出入证Service业务层处理
 * 
 * @author dgtly
 * @date 2020-02-15
 */
@Service
public class EntryPassServiceImpl implements IEntryPassService 
{
    @Autowired
    private EntryPassMapper entryPassMapper;

    /**
     * 查询出入证
     * 
     * @param id 出入证ID
     * @return 出入证
     */
    @Override
    public EntryPass selectEntryPassByUserId(Long userId)
    {
        return entryPassMapper.selectEntryPassByUserId(userId);
    }

    /**
     * 查询出入证列表
     * 
     * @param entryPass 出入证
     * @return 出入证
     */
    @Override
    public List<EntryPass> selectEntryPassList(EntryPass entryPass)
    {
        return entryPassMapper.selectEntryPassList(entryPass);
    }

    /**
     * 新增出入证
     * 
     * @param entryPass 出入证
     * @return 结果
     */
    @Override
    public int insertEntryPass(EntryPass entryPass)
    {
        return entryPassMapper.insertEntryPass(entryPass);
    }

    /**
     * 修改出入证
     * 
     * @param entryPass 出入证
     * @return 结果
     */
    @Override
    public int updateEntryPass(EntryPass entryPass)
    {
        return entryPassMapper.updateEntryPass(entryPass);
    }

    /**
     * 删除出入证对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteEntryPassByIds(String ids)
    {
        return entryPassMapper.deleteEntryPassByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除出入证信息
     * 
     * @param id 出入证ID
     * @return 结果
     */
    @Override
    public int deleteEntryPassById(Long id)
    {
        return entryPassMapper.deleteEntryPassById(id);
    }



}
