package com.dgtly.system.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.UserTemperatureMapper;
import com.dgtly.system.domain.UserTemperature;
import com.dgtly.system.service.IUserTemperatureService;
import com.dgtly.common.core.text.Convert;

/**
 * 体温信息Service业务层处理
 * 
 * @author dgtly
 * @date 2020-02-15
 */
@Service
public class UserTemperatureServiceImpl implements IUserTemperatureService 
{
    @Autowired
    private UserTemperatureMapper userTemperatureMapper;

    /**
     * 查询体温信息
     * 
     * @param id 体温信息ID
     * @return 体温信息
     */
    @Override
    public UserTemperature selectUserTemperatureById(Long id)
    {
        return userTemperatureMapper.selectUserTemperatureById(id);
    }

    /**
     * 查询体温信息列表
     * 
     * @param userTemperature 体温信息
     * @return 体温信息
     */
    @Override
    public List<UserTemperature> selectUserTemperatureList(UserTemperature userTemperature)
    {
        return userTemperatureMapper.selectUserTemperatureList(userTemperature);
    }

    /**
     * 新增体温信息
     * 
     * @param userTemperature 体温信息
     * @return 结果
     */
    @Override
    public int insertUserTemperature(UserTemperature userTemperature)
    {
        userTemperature.setCreateTime(DateUtils.getNowDate());
        return userTemperatureMapper.insertUserTemperature(userTemperature);
    }

    /**
     * 修改体温信息
     * 
     * @param userTemperature 体温信息
     * @return 结果
     */
    @Override
    public int updateUserTemperature(UserTemperature userTemperature)
    {
        userTemperature.setUpdateTime(DateUtils.getNowDate());
        return userTemperatureMapper.updateUserTemperature(userTemperature);
    }

    /**
     * 删除体温信息对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteUserTemperatureByIds(String ids)
    {
        return userTemperatureMapper.deleteUserTemperatureByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除体温信息信息
     * 
     * @param id 体温信息ID
     * @return 结果
     */
    @Override
    public int deleteUserTemperatureById(Long id)
    {
        return userTemperatureMapper.deleteUserTemperatureById(id);
    }
}
